"""

阿里云升级配置后，磁盘手工需要扩容: https://zhuanlan.zhihu.com/p/242619035

Error constructing proxy for org.gnome.Terminal:/org/gnome/Terminal/Factory0: 为 org.gnome.Terminal 调用 StartServiceByName 出错：已到超时限制
https://www.cnblogs.com/ztguang/p/12644799.html
dbus-launch gnome-terminal
"""